@@ -34,7 +34,7 @@ class ObjectHydratorTest extends HydrationTestCase
 {
     use MockBuilderCompatibilityTools;
 
-    /** @psalm-return list<array{mixed}> */
+    /** @phpstan-return list<array{mixed}> */
     public static function provideDataForUserEntityResult(): array
     {
         return [
@@ -43,7 +43,7 @@ class ObjectHydratorTest extends HydrationTestCase
         ];
     }
 
-    /** @psalm-return list<array{mixed, mixed}> */
+    /** @phpstan-return list<array{mixed, mixed}> */
     public static function provideDataForMultipleRootEntityResult(): array
     {
         return [
@@ -54,7 +54,7 @@ class ObjectHydratorTest extends HydrationTestCase
         ];
     }
 
-    /** @psalm-return list<array{mixed}> */
+    /** @phpstan-return list<array{mixed}> */
     public static function provideDataForProductEntityResult(): array
     {
         return [
@@ -1036,7 +1036,7 @@ class ObjectHydratorTest extends HydrationTestCase
         $proxyFactory->expects(self::once())
                      ->method('getProxy')
                      ->with(self::equalTo(ECommerceShipping::class), ['id' => 42])
-                     ->will(self::returnValue($proxyInstance));
+                     ->willReturn($proxyInstance);
 
         $this->entityManager->setProxyFactory($proxyFactory);
 
@@ -1084,7 +1084,7 @@ class ObjectHydratorTest extends HydrationTestCase
         $proxyFactory->expects(self::once())
                      ->method('getProxy')
                      ->with(self::equalTo(ECommerceShipping::class), ['id' => 42])
-                     ->will(self::returnValue($proxyInstance));
+                     ->willReturn($proxyInstance);
 
         $this->entityManager->setProxyFactory($proxyFactory);
 
